@@ -137,6 +137,15 @@ gedit_spell_plugin_init (GeditSpellPlugin *plugin)
 	plugin->priv = gedit_spell_plugin_get_instance_private (plugin);
 }
 
+static GspellChecker *
+get_spell_checker (GeditDocument *doc)
+{
+	GspellTextBuffer *gspell_buffer;
+
+	gspell_buffer = gspell_text_buffer_get_from_gtk_text_buffer (GTK_TEXT_BUFFER (doc));
+	return gspell_text_buffer_get_spell_checker (gspell_buffer);
+}
+
 static const GspellLanguage *
 get_language_from_metadata (GeditDocument *doc)
 {
@@ -174,7 +183,6 @@ check_spell_cb (GSimpleAction *action,
 
 	navigator = gspell_navigator_text_view_new (GTK_TEXT_VIEW (view));
 	dialog = gspell_checker_dialog_new (GTK_WINDOW (priv->window), navigator);
-	g_object_unref (navigator);
 
 	gtk_widget_show (dialog);
 }
@@ -216,7 +224,7 @@ set_language_cb (GSimpleAction *action,
 	doc = gedit_window_get_active_document (priv->window);
 	g_return_if_fail (doc != NULL);
 
-	checker = gspell_text_buffer_get_spell_checker (GTK_TEXT_BUFFER (doc));
+	checker = get_spell_checker (doc);
 	g_return_if_fail (checker != NULL);
 
 	lang = gspell_checker_get_language (checker);
@@ -308,10 +316,10 @@ inline_checker_change_state_cb (GSimpleAction *action,
 	view = gedit_window_get_active_view (priv->window);
 	if (view != NULL)
 	{
-		GspellInlineCheckerTextView *inline_checker;
+		GspellTextView *gspell_view;
 
-		inline_checker = gspell_text_view_get_inline_checker (GTK_TEXT_VIEW (view));
-		gspell_inline_checker_text_view_set_enabled (inline_checker, active);
+		gspell_view = gspell_text_view_get_from_gtk_text_view (GTK_TEXT_VIEW (view));
+		gspell_text_view_set_inline_spell_checking (gspell_view, active);
 
 		g_simple_action_set_state (action, g_variant_new_boolean (active));
 	}
@@ -361,14 +369,14 @@ update_ui (GeditSpellPlugin *plugin)
 	if (tab != NULL &&
 	    gedit_tab_get_state (tab) == GEDIT_TAB_STATE_NORMAL)
 	{
-		GspellInlineCheckerTextView *inline_checker;
-		gboolean inline_checker_enabled;
+		GspellTextView *gspell_view;
+		gboolean inline_checking_enabled;
 
-		inline_checker = gspell_text_view_get_inline_checker (GTK_TEXT_VIEW (view));
-		inline_checker_enabled = gspell_inline_checker_text_view_get_enabled (inline_checker);
+		gspell_view = gspell_text_view_get_from_gtk_text_view (GTK_TEXT_VIEW (view));
+		inline_checking_enabled = gspell_text_view_get_inline_spell_checking (gspell_view);
 
 		g_action_change_state (inline_checker_action,
-				       g_variant_new_boolean (inline_checker_enabled));
+				       g_variant_new_boolean (inline_checking_enabled));
 	}
 }
 
@@ -379,7 +387,7 @@ setup_inline_checker_from_metadata (GeditSpellPlugin *plugin,
 	GeditDocument *doc;
 	gboolean enabled = FALSE;
 	gchar *enabled_str;
-	GspellInlineCheckerTextView *inline_checker;
+	GspellTextView *gspell_view;
 	GeditView *active_view;
 
 	doc = GEDIT_DOCUMENT (gtk_text_view_get_buffer (GTK_TEXT_VIEW (view)));
@@ -391,8 +399,8 @@ setup_inline_checker_from_metadata (GeditSpellPlugin *plugin,
 		g_free (enabled_str);
 	}
 
-	inline_checker = gspell_text_view_get_inline_checker (GTK_TEXT_VIEW (view));
-	gspell_inline_checker_text_view_set_enabled (inline_checker, enabled);
+	gspell_view = gspell_text_view_get_from_gtk_text_view (GTK_TEXT_VIEW (view));
+	gspell_text_view_set_inline_spell_checking (gspell_view, enabled);
 
 	/* In case that the view is the active one we mark the spell action */
 	active_view = gedit_window_get_active_view (plugin->priv->window);
@@ -436,7 +444,7 @@ on_document_loaded (GeditDocument    *doc,
 	GeditTab *tab;
 	GeditView *view;
 
-	checker = gspell_text_buffer_get_spell_checker (GTK_TEXT_BUFFER (doc));
+	checker = get_spell_checker (doc);
 
 	if (checker != NULL)
 	{
@@ -465,12 +473,12 @@ on_document_saved (GeditDocument *doc,
 	GeditView *view;
 	GspellChecker *checker;
 	const gchar *language_code = NULL;
-	GspellInlineCheckerTextView *inline_checker;
-	gboolean inline_checker_enabled;
+	GspellTextView *gspell_view;
+	gboolean inline_checking_enabled;
 
 	/* Make sure to save the metadata here too */
 
-	checker = gspell_text_buffer_get_spell_checker (GTK_TEXT_BUFFER (doc));
+	checker = get_spell_checker (doc);
 
 	if (checker != NULL)
 	{
@@ -480,12 +488,12 @@ on_document_saved (GeditDocument *doc,
 	tab = gedit_tab_get_from_document (doc);
 	view = gedit_tab_get_view (tab);
 
-	inline_checker = gspell_text_view_get_inline_checker (GTK_TEXT_VIEW (view));
-	inline_checker_enabled = gspell_inline_checker_text_view_get_enabled (inline_checker);
+	gspell_view = gspell_text_view_get_from_gtk_text_view (GTK_TEXT_VIEW (view));
+	inline_checking_enabled = gspell_text_view_get_inline_spell_checking (gspell_view);
 
 	gedit_document_set_metadata (doc,
 	                             GEDIT_METADATA_ATTRIBUTE_SPELL_ENABLED,
-				     inline_checker_enabled ? SPELL_ENABLED_STR : NULL,
+				     inline_checking_enabled ? SPELL_ENABLED_STR : NULL,
 	                             GEDIT_METADATA_ATTRIBUTE_SPELL_LANGUAGE,
 	                             language_code,
 	                             NULL);
@@ -502,10 +510,14 @@ activate_spell_checking_in_view (GeditSpellPlugin *plugin,
 	/* It is possible that a GspellChecker has already been set, for example
 	 * if a GeditTab has moved to another window.
 	 */
-	if (gspell_text_buffer_get_spell_checker (GTK_TEXT_BUFFER (doc)) == NULL)
+	if (get_spell_checker (doc) == NULL)
 	{
-		const GspellLanguage *lang = get_language_from_metadata (doc);
-		GspellChecker *checker = gspell_checker_new (lang);
+		const GspellLanguage *lang;
+		GspellChecker *checker;
+		GspellTextBuffer *gspell_buffer;
+
+		lang = get_language_from_metadata (doc);
+		checker = gspell_checker_new (lang);
 
 		g_signal_connect_object (checker,
 					 "notify::language",
@@ -513,7 +525,8 @@ activate_spell_checking_in_view (GeditSpellPlugin *plugin,
 					 doc,
 					 0);
 
-		gspell_text_buffer_set_spell_checker (GTK_TEXT_BUFFER (doc), checker);
+		gspell_buffer = gspell_text_buffer_get_from_gtk_text_buffer (GTK_TEXT_BUFFER (doc));
+		gspell_text_buffer_set_spell_checker (gspell_buffer, checker);
 		g_object_unref (checker);
 
 		setup_inline_checker_from_metadata (plugin, view);
@@ -554,16 +567,18 @@ static void
 deactivate_spell_checking_in_view (GeditSpellPlugin *plugin,
 				   GeditView        *view)
 {
-	GtkTextBuffer *buffer;
-	GspellInlineCheckerTextView *inline_checker;
+	GtkTextBuffer *gtk_buffer;
+	GspellTextBuffer *gspell_buffer;
+	GspellTextView *gspell_view;
 
 	disconnect_view (plugin, view);
 
-	buffer = gtk_text_view_get_buffer (GTK_TEXT_VIEW (view));
-	gspell_text_buffer_set_spell_checker (buffer, NULL);
+	gtk_buffer = gtk_text_view_get_buffer (GTK_TEXT_VIEW (view));
+	gspell_buffer = gspell_text_buffer_get_from_gtk_text_buffer (gtk_buffer);
+	gspell_text_buffer_set_spell_checker (gspell_buffer, NULL);
 
-	inline_checker = gspell_text_view_get_inline_checker (GTK_TEXT_VIEW (view));
-	gspell_inline_checker_text_view_set_enabled (inline_checker, FALSE);
+	gspell_view = gspell_text_view_get_from_gtk_text_view (GTK_TEXT_VIEW (view));
+	gspell_text_view_set_inline_spell_checking (gspell_view, FALSE);
 }
 
 static void
